@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 import os
 from django.conf import settings
-from django.db.models import get_app
+from django.utils.importlib import import_module
+
 
 class BaseTask(object):
     """
@@ -51,6 +52,6 @@ def get_apps_locations(test_labels, all_apps=False):
     """
     Returns list of paths to tested apps
     """
-    return [os.path.dirname(get_app(app_name.split('.')[-1]).__file__) \
+    return [os.path.dirname(os.path.normpath(import_module(app_name).__file__)) \
             for app_name in get_apps_under_test(test_labels, all_apps)]
 
